Documentation
¶
Index ¶
- type IngressReconciler
- func (r *IngressReconciler) Close() error
- func (r *IngressReconciler) GetCertificate(chi *tls.ClientHelloInfo) (*tls.Certificate, error)
- func (r *IngressReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
- func (r *IngressReconciler) ServeHTTP(w http.ResponseWriter, req *http.Request)
- func (r *IngressReconciler) SetupWithManager(mgr ctrl.Manager) (err error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IngressReconciler ¶
type IngressReconciler struct {
// From manager via SetupWithManager.
client.Client
record.EventRecorder
*rest.Config
*kubernetes.Clientset
// CLI args.
GetIngressLoadBalancerIngress func(ctx context.Context) (*networkingv1.IngressLoadBalancerIngress, error)
IngressClassName string
// Portforward to a Service-selected Pod instead of using Service DNS.
// Useful for when running outside of the cluster we're reconciling.
Portforward bool
// contains filtered or unexported fields
}
IngressReconciler reconciles a Ingress object
func (*IngressReconciler) Close ¶
func (r *IngressReconciler) Close() error
func (*IngressReconciler) GetCertificate ¶
func (r *IngressReconciler) GetCertificate(chi *tls.ClientHelloInfo) (*tls.Certificate, error)
func (*IngressReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*IngressReconciler) ServeHTTP ¶
func (r *IngressReconciler) ServeHTTP(w http.ResponseWriter, req *http.Request)
func (*IngressReconciler) SetupWithManager ¶
func (r *IngressReconciler) SetupWithManager(mgr ctrl.Manager) (err error)
SetupWithManager sets up the controller with the Manager.
Click to show internal directories.
Click to hide internal directories.